@@ -50,9 +50,9 @@ pub fn is_pre_release_version(semver: &Version) -> bool {
     semver.major == 0
 }
 
-pub fn is_top_level_package(manifest_path: &Utf8Path, handle: &git::easy::Handle) -> bool {
+pub fn is_top_level_package(manifest_path: &Utf8Path, repo: &git::Repository) -> bool {
     manifest_path
-        .strip_prefix(handle.work_tree().as_ref().expect("repo with working tree"))
+        .strip_prefix(repo.work_dir().as_ref().expect("repo with working tree"))
         .map_or(false, |p| p.components().count() == 1)
 }
 
@@ -97,16 +97,16 @@ pub fn package_by_id<'a>(meta: &'a Metadata, id: &PackageId) -> &'a Package {
         .expect("workspace members are in packages")
 }
 
-pub fn tag_prefix<'p>(package: &'p Package, handle: &git::easy::Handle) -> Option<&'p str> {
-    if is_top_level_package(&package.manifest_path, handle) {
+pub fn tag_prefix<'p>(package: &'p Package, repo: &git::Repository) -> Option<&'p str> {
+    if is_top_level_package(&package.manifest_path, repo) {
         None
     } else {
         Some(&package.name)
     }
 }
 
-pub fn tag_name(package: &Package, version: &semver::Version, handle: &git::easy::Handle) -> String {
-    tag_name_inner(tag_prefix(package, handle), version)
+pub fn tag_name(package: &Package, version: &semver::Version, repo: &git::Repository) -> String {
+    tag_name_inner(tag_prefix(package, repo), version)
 }
 
 fn tag_name_inner(package_name: Option<&str>, version: &semver::Version) -> String {
@@ -300,7 +300,7 @@ mod tests {
 }
 
 pub fn time_to_offset_date_time(time: git::actor::Time) -> OffsetDateTime {
-    time::OffsetDateTime::from_unix_timestamp(time.time as i64)
+    time::OffsetDateTime::from_unix_timestamp(time.seconds_since_unix_epoch as i64)
         .expect("always valid unix time")
-        .replace_offset(time::UtcOffset::from_whole_seconds(time.offset).expect("valid offset"))
+        .replace_offset(time::UtcOffset::from_whole_seconds(time.offset_in_seconds).expect("valid offset"))
 }
